{ config, ... }: {

  imports = [
    ./hardware-configuration.nix
    ../../server.nix
    ../../features/systemd-boot.nix
    ../../features/podman.nix
  ];

  networking.hostName = "blueberry";
  system.stateVersion = "23.05";
  services.qemuGuest.enable = true;

  sops.secrets."saerro/database/url" = {
    sopsFile = ../../../secrets/blueberry/default.yaml;
  };

  sops.secrets."saerro/database/password" = {
    sopsFile = ../../../secrets/blueberry/default.yaml;
  };

  sops.secrets."saerro/ws_addr" = {
    sopsFile = ../../../secrets/blueberry/default.yaml;
  };

  pods.enable = true;
  pods.pods.saerro = {
    routes = let 
      route = { port = "8003"; }; 
    in {
      "saerro.ps2.live" = route;
      "saerro-new.ps2.live" = route;
    };
    
    exportPorts = [
      "0.0.0.0:8003:8003"
    ];

    containers = {
      api = {
        image = "ghcr.io/genudine/saerro/api:latest";
        environment = {
          PORT = "8003";
          WEBSOCKET_HEALTHCHECK = "http://127.0.0.1:8004/healthz";
        };
        secrets = {
          DATABASE_ADDR = config.sops.secrets."saerro/database/url".path;
        };
        ports = [
          "8003:8003";
        ];
      };
    };
  };
}
